var _CSSProperty = require('./CSSProperty');

var _CSSProperty2 = _interopRequireDefault(_CSSProperty);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

describe('getPropertyValue', function () {
  test('should generate css value from string', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'xs', 'align-self')).toEqual('center');
  });

  test('should not generate css value from string if not provided on props', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'xs', 'order')).toEqual(null);
  });

  test('should generate css value from string if breakpoint is == xs', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'xs', 'align-self')).toEqual('center');
  });

  test('should not generate css value from string if breakpoint is > xs', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'md', 'align-self')).toEqual(null);
  });

  test('should generate css value from object if it matches current breakpoint', function () {
    var mockProps = { alignSelf: { lg: 'center' } };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'lg', 'align-self')).toEqual('center');
  });

  test('should not generate css value from object if does not match current breakpoint', function () {
    var mockProps = { alignSelf: { sm: 'center' } };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'lg', 'align-self')).toEqual(null);
  });

  test('should generate value when it is 0 (falsy)', function () {
    var mockProps = { order: { sm: 0 } };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'sm', 'order')).toEqual('0');
  });

  test('should not generate value when it is null (falsy)', function () {
    var mockProps = { order: { sm: false } };
    expect((0, _CSSProperty.getPropertyValue)(mockProps, 'sm', 'order')).toEqual(null);
  });
});

describe('CSSProperty', function () {
  test('should generte css for valid property', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty2['default'])(mockProps, 'xs', 'align-self').join('')).toContain('align-self: center');
  });

  test('should not generte css for invalid property', function () {
    var mockProps = { alignSelf: 'center' };
    expect((0, _CSSProperty2['default'])(mockProps, 'xs', 'order')).toEqual(null);
  });

  test('should generte css nested property', function () {
    var mockProps = { alignSelf: { sm: 'center' } };
    expect((0, _CSSProperty2['default'])(mockProps, 'sm', 'align-self').join('')).toContain('align-self: center');
  });

  test('should generte order even when 0', function () {
    var mockProps = { order: { sm: 0 } };
    expect((0, _CSSProperty2['default'])(mockProps, 'sm', 'order').join('')).toContain('order: 0');
  });
});